@@ -13,6 +13,11 @@ YD_ENV_VAR_PREFIX = "YD_VAR_"
 ENV_VAR_SUB_PREFIX = "env:"
 RAND_VAR_SIZE = 0xFFF
 
+# Alternative env.var names
+YD_KEY_ALT = "YD_API_KEY_ID"
+YD_SECRET_ALT = "YD_API_KEY_SECRET"
+YD_URL_ALT = "YD_API_URL"
+
 TASK_BATCH_SIZE_DEFAULT = 1000
 MAX_PARALLEL_TASK_BATCH_UPLOAD_THREADS = 1
 MAX_BATCH_SUBMIT_ATTEMPTS = 4  # Initial attempt plus retries
@@ -59,6 +64,7 @@ HIGHLIGHTED_STATES = [
     r"(?P<active>TARGET)",
     r"(?P<active>ALIVE)",
     r"(?P<active>MATCHING)",
+    r"(?P<active>MAYBE MATCHING)",
     r"(?P<cancelled>ABORTED)",
     r"(?P<cancelled>CANCELLED)",
     r"(?P<cancelled>CANCELLING)",
@@ -138,6 +144,7 @@ RN_UPDATE_GROUP_REQUEST = "UpdateGroupRequest"
 PROP_ACCESS_DELEGATES = "accessDelegates"
 PROP_ADMIN_GROUP = "adminGroup"
 PROP_AUTOSCALING_MAX_NODES = "autoscalingMaxNodes"
+PROP_CREATED_BY_ID = "createdById"
 PROP_CREATED_BY_USER_ID = "createdByUserId"
 PROP_CREATED_TIME = "createdTime"
 PROP_CREDENTIAL = "credential"
@@ -147,6 +154,7 @@ PROP_DELETABLE = "deletable"
 PROP_DESCRIPTION = "description"
 PROP_EFFECTIVE_FROM = "effectiveFrom"
 PROP_EFFECTIVE_UNTIL = "effectiveUntil"
+PROP_GLOBAL = "global"
 PROP_GROUPS = "groups"
 PROP_ID = "id"
 PROP_IMAGE = "image"
@@ -157,12 +165,16 @@ PROP_KEYRING = "keyring"
 PROP_KEYRING_NAME = "keyringName"
 PROP_NAME = "name"
 PROP_NAMESPACE = "namespace"
+PROP_NAMESPACES = "namespaces"
 PROP_OPTIONS = "options"
 PROP_OS_TYPE = "osType"
 PROP_RANGE = "range"
+PROP_REMAINING_HOURS = "remainingHours"
 PROP_REQUIREMENT_CREATED_FROM = "requirementCreatedFromId"
 PROP_RESOURCE = "resource"
+PROP_ROLE = "role"
 PROP_ROLES = "roles"
+PROP_SCOPE = "scope"
 PROP_SOURCE = "source"
 PROP_SOURCES = "sources"
 PROP_SOURCE_CREATED_FROM = "sourceCreatedFromId"
